@@ -2,7 +2,7 @@
 #
 # This file only contains a selection of the most common options. For a full
 # list see the documentation:
-# http://www.sphinx-doc.org/en/master/config
+# https://www.sphinx-doc.org/en/master/usage/configuration.html
 
 # -- Path setup --------------------------------------------------------------
 
@@ -10,7 +10,7 @@
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
-import os
+# from meshplex import __version__ as release
 
 # import sys
 # sys.path.insert(0, os.path.abspath('.'))
@@ -22,21 +22,9 @@ master_doc = "index"
 # -- Project information -----------------------------------------------------
 
 project = "meshplex"
-copyright = "2017-2021, Nico Schlömer"
+copyright = "2017-2022, Nico Schlömer"
 author = "Nico Schlömer"
 
-#
-# https://packaging.python.org/single_source_version/
-this_dir = os.path.abspath(os.path.dirname(__file__))
-about = {}
-about_file = os.path.join(this_dir, "..", "meshplex", "__about__.py")
-with open(about_file) as f:
-    exec(f.read(), about)
-# The short X.Y version.
-# version = ".".join(about["__version__"].split(".")[:2])
-# The full version, including alpha/beta/rc tags.
-release = about["__version__"]
-
 
 # -- General configuration ---------------------------------------------------
 
